@@ -355,15 +355,22 @@ class Cursor(common.DBAPICursor):
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        # in order to stop fetching next batch, we are limiting to one batch - 1000 records
-        self.rows_count += len(self._batch)
-        if self.rows_count <= 1000:
-            row = self._batch
-        else:
-            row = None
-            # reset row counter for next query execution
-            self.rows_count = 0
-        return row
+        # # in order to stop fetching next batch, we are limiting to one batch - 1000 records
+        # self.rows_count += len(self._batch)
+        # if self.rows_count <= 1000:
+        #     row = self._batch
+        # else:
+        #     row = None
+        #     # reset row counter for next query execution
+        #     self.rows_count = 0
+
+        row = self._batch.pop()
+        for i in row:
+            self.rows_count += 1
+            if self.rows_count <= 1000:
+                return row
+            else:
+                return None
 
     def poll(self, get_progress_update=True):
         """Poll for and return the raw status data provided by the Hive Thrift REST API.
@@ -394,7 +401,7 @@ if __name__ == '__main__':
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="tpc_10gb",
+                         database="tpc_330mb",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
